@@ -21,6 +21,11 @@ from coderfastapi.lib.security.policies.authentication.jwt.providers.user import
 
 log = logging.getLogger(__name__)
 T = TypeVar("T", bound=Request)
+DEFAULT_PROVIDERS: set[JWTDataProvider] = {
+    ExpirationDataProvider(),
+    RecoveryDataProvider(),
+    UserDataProvider(),
+}
 
 
 class JWTAuthenticationPolicy(AuthenticationPolicy):
@@ -32,11 +37,7 @@ class JWTAuthenticationPolicy(AuthenticationPolicy):
         self,
         secret_key: str,
         algorithm: str = "HS256",
-        providers: set[JWTDataProvider] = {
-            ExpirationDataProvider(),
-            RecoveryDataProvider(),
-            UserDataProvider(),
-        },
+        providers: set[JWTDataProvider] = DEFAULT_PROVIDERS,
     ) -> None:
         self.secret_key = secret_key
         self.algorithm = algorithm
@@ -79,7 +80,10 @@ class JWTAuthenticationPolicy(AuthenticationPolicy):
     def create_access_token(self, **kwargs) -> str:
         data = {}
         for provider in self.providers:
-            data.update(provider.parse_to_encode(kwargs))
+            try:
+                data.update(provider.parse_to_encode(kwargs))
+            except KeyError:
+                pass
         return self._create_token(data)
 
     def _create_token(self, data: dict[str, Any]) -> str:
